@@ -25,6 +25,7 @@
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QDialog>
+#include <QDesktopServices>
 #include <iostream>
 
 using namespace std;
@@ -191,6 +192,9 @@ MainWindow::MainWindow(QWidget *parent): QDialog(parent) {
 
 	logsDialog = new LogsDialog(this);
 
+        friendsMgmtDialog = new FriendsMgmtDialog(this, &twitter, &userpicsDownloader);
+        friendsMgmtDialog->setModal(true);
+
 	acceptClose = false;
 
 	connect(statusTextEdit, SIGNAL(returnPressed()), this, SLOT(sendStatus()));
@@ -202,6 +206,7 @@ MainWindow::MainWindow(QWidget *parent): QDialog(parent) {
 	connect(optionsPushButton, SIGNAL(pressed()), optionsDialog, SLOT(showNormal()));
 	connect(logsPushButton, SIGNAL(pressed()), logsDialog, SLOT(showNormal()));
 	connect(exitPushButton, SIGNAL(pressed()), this, SLOT(quit()));
+        connect(friendsPushButton, SIGNAL(pressed()), friendsMgmtDialog, SLOT(showNormal()));
 
 	connect(&twitter, SIGNAL(updated(const QByteArray&, int)), this, SLOT(updated(const QByteArray&, int)));
 	connect(&twitter, SIGNAL(statusUpdated()), this, SLOT(statusUpdated()));
@@ -237,7 +242,7 @@ MainWindow::MainWindow(QWidget *parent): QDialog(parent) {
 }
 
 void MainWindow::postTwitPic() {
-	QString fileName = QFileDialog::getOpenFileName(this, tr("Pick an image"), QDir::homePath(), tr("Image Files (*.png *.jpg *.jpeg *.bmp)"));
+	QString fileName = QFileDialog::getOpenFileName(this, tr("Pick an image"), QDir::homePath(), tr("Image Files (*.png *.jpg *.jpeg *.bmp *.JPG *.JPEG *.PNG *.GIF *.BMP)"));
 	if (fileName.isEmpty())
 		return;
 	TwitPicDialog dialog(fileName, this);
@@ -282,8 +287,10 @@ void MainWindow::loadState() {
 	messagesPerTray = settings.value("messagesPerTray", DEFAULT_MESSAGES_PER_TRAY).toInt();
 	verticalAlignControl = settings.value("verticalAlignControl", true).toBool();
 	placeTabsVertically = settings.value("placeTabsVertically", true).toBool();
+	keepFocusAfterUpdate = settings.value("keepFocusAfterUpdate", true).toBool();
 	updatesNotification = settings.value("updatesNotification", true).toBool();
 	usernameUnderAvatar = settings.value("usernameUnderAvatar", true).toBool();
+	openUserProfileInBrowser = settings.value("openUserProfileInBrowser", true).toBool();
 	twitter.setServiceAPIURL(settings.value("serviceAPIURL", "http://twitter.com").toString());
 	twitter.setServiceBaseURL(settings.value("serviceBaseURL", "http://twitter.com").toString());
 	greetingMessageLabel->setText(settings.value("greetingMessage", "What are you doing?").toString());
@@ -311,7 +318,9 @@ void MainWindow::loadState() {
 	optionsDialog->updatesNotificationCheckBox->setCheckState(updatesNotification ? Qt::Checked : Qt::Unchecked);
 	optionsDialog->verticalControlCheckBox->setCheckState(verticalAlignControl ? Qt::Checked : Qt::Unchecked);
 	optionsDialog->placeTabsVerticallyCheckBox->setCheckState(placeTabsVertically ? Qt::Checked : Qt::Unchecked);
+	optionsDialog->keepFocusAfterUpdateCheckBox->setCheckState(keepFocusAfterUpdate ? Qt::Checked : Qt::Unchecked);
 	optionsDialog->usernameUnderAvatarCheckBox->setCheckState(usernameUnderAvatar ? Qt::Checked : Qt::Unchecked);
+	optionsDialog->openUserProfileInBrowserCheckBox->setCheckState(openUserProfileInBrowser ? Qt::Checked : Qt::Unchecked);
 	optionsDialog->serviceBaseURLLineEdit->setText(twitter.getServiceBaseURL());
 	optionsDialog->serviceAPIURLLineEdit->setText(twitter.getServiceAPIURL());
 	optionsDialog->usernameLineEdit->setText(username);
@@ -351,15 +360,15 @@ void MainWindow::loadState() {
 		for (int i = 0; i < size; ++i) {
 			settings.setArrayIndex(i);
 			if (i == 0) {
-				twitterTabs[tab].lastId = settings.value("messageId").toUInt();
+				twitterTabs[tab].lastId = settings.value("messageId").toULongLong();
 			}
 			twitterTabs[tab].twitterWidget->addItem(
 				settings.value("userpic").toString(),
 				settings.value("username").toString(),
 				settings.value("status").toString(),
 				QDateTime::fromString(settings.value("time").toString(), "yyyy-MM-dd hh:mm:ss"),
-				settings.value("messageId").toUInt(),
-				settings.value("replyStatusId").toUInt(),
+				settings.value("messageId").toULongLong(),
+				settings.value("replyStatusId").toULongLong(),
 				-1,
 				twitter.getServiceBaseURL(),
 				username
@@ -385,9 +394,13 @@ void MainWindow::setRetweetTag() {
 }
 
 void MainWindow::openUser(const QString &user) {
-    tabWidget->setCurrentIndex(CUSTOM_TWITTER_TAB);
-    customUsernameLineEdit->setText(user);
-    customUsernameChanged();
+	if (openUserProfileInBrowser) {
+		QDesktopServices::openUrl(QUrl(twitter.getServiceBaseURL() + "/" + user));
+	} else {
+		tabWidget->setCurrentIndex(CUSTOM_TWITTER_TAB);
+		customUsernameLineEdit->setText(user);
+		customUsernameChanged();
+	}
 }
 
 void MainWindow::openSearch(const QString &query) {
@@ -411,7 +424,9 @@ void MainWindow::sendStatus() {
 	statusTextEdit->setText("");
 	charsLeftLabel->setText(QString::number(statusTextEdit->getMaxStatusCharacter()));
 	charsLeftLabel->setForegroundRole(QPalette::Light);
-	twitterTabs[tabWidget->currentIndex()].twitterWidget->setFocus(Qt::OtherFocusReason);
+	if (!keepFocusAfterUpdate) {
+		twitterTabs[tabWidget->currentIndex()].twitterWidget->setFocus(Qt::OtherFocusReason);
+	}
 }
 
 void MainWindow::updateTimeline() {
@@ -451,9 +466,11 @@ void MainWindow::saveState() {
 	messagesPerTray = optionsDialog->messagesPerTrayLineEdit->text().toInt();
 	retweetTag = optionsDialog->retweetTagEdit->text();
 	retweetTagPlace = optionsDialog->retweetAtEnd->checkState() == Qt::Checked;
+	openUserProfileInBrowser = optionsDialog->openUserProfileInBrowserCheckBox->checkState() == Qt::Checked;
 	bool proxySavePassword = optionsDialog->proxySavePasswordCheckBox->checkState() == Qt::Checked;
 	verticalAlignControl = optionsDialog->verticalControlCheckBox->checkState() == Qt::Checked;
 	placeTabsVertically = optionsDialog->placeTabsVerticallyCheckBox->checkState() == Qt::Checked;
+	keepFocusAfterUpdate = optionsDialog->keepFocusAfterUpdateCheckBox->checkState() == Qt::Checked;
 	updatesNotification = optionsDialog->updatesNotificationCheckBox->checkState() == Qt::Checked;
 	usernameUnderAvatar = optionsDialog->usernameUnderAvatarCheckBox->checkState() == Qt::Checked;
 	greetingMessageLabel->setText(optionsDialog->greetingMessageLineEdit->text());
@@ -477,8 +494,10 @@ void MainWindow::saveState() {
 	settings.setValue("retweetTagPlace", retweetTagPlace);
 	settings.setValue("verticalAlignControl", verticalAlignControl);
 	settings.setValue("placeTabsVertically", placeTabsVertically);
+	settings.setValue("keepFocusAfterUpdate", keepFocusAfterUpdate);
 	settings.setValue("updatesNotification", updatesNotification);
 	settings.setValue("usernameUnderAvatar", usernameUnderAvatar);
+	settings.setValue("openUserProfileInBrowser", openUserProfileInBrowser);
 	settings.setValue("serviceBaseURL", twitter.getServiceBaseURL());
 	settings.setValue("serviceAPIURL", twitter.getServiceAPIURL());
 	settings.setValue("greetingMessage", greetingMessageLabel->text());
@@ -508,12 +527,12 @@ void MainWindow::saveState() {
 			try {
 				const TwitterWidgetItem &item = twitterTabs[tab].twitterWidget->getItem(i);
 				settings.setArrayIndex(i);
-				settings.setValue("userpic", item.cacheUserpic);
-				settings.setValue("username", item.cacheUsername);
-				settings.setValue("status", item.cacheStatus);
-				settings.setValue("time", item.cacheTime.toString("yyyy-MM-dd hh:mm:ss"));
-				settings.setValue("messageId", item.cacheMessageId);
-				settings.setValue("replyStatusId", item.cacheReplyStatusId);
+				settings.setValue("userpic", item.cacheUserpic());
+				settings.setValue("username", item.cacheUsername());
+				settings.setValue("status", item.cacheStatus());
+				settings.setValue("time", item.cacheTime().toString("yyyy-MM-dd hh:mm:ss"));
+				settings.setValue("messageId", item.cacheMessageId());
+				settings.setValue("replyStatusId", item.cacheReplyStatusId());
 			} catch (const QwitException &exception) {
 				cerr << "Exception catched: " << qPrintable(exception.message) << endl;
 			}
@@ -640,7 +659,7 @@ void MainWindow::updated(const QByteArray &buffer, int type) {
 	QDomNode node = root.firstChild();
 	QString html = "";
 	QString trayMessage = "";
-	uint maxId = twitterTabs[type].lastId;
+	quint64 maxId = twitterTabs[type].lastId;
 	int j = 0;
 	while (!node.isNull()) {
 		if (node.toElement().tagName() != "status") {
@@ -648,18 +667,18 @@ void MainWindow::updated(const QByteArray &buffer, int type) {
 		}
 		QDomNode node2 = node.firstChild();
 		QString message = "", timeStr = "", user = "", image = "";
-		uint id = 0, replyUserID = 0, replyStatusId = 0;
+		quint64 id = 0, replyUserID = 0, replyStatusId = 0;
 		while (!node2.isNull()) {
 			if (node2.toElement().tagName() == "created_at") {
 				timeStr = node2.toElement().text();
 			} else if (node2.toElement().tagName() == "text") {
 				message = node2.toElement().text();
 			} else if (node2.toElement().tagName() == "id") {
-				id = node2.toElement().text().toUInt();
+				id = node2.toElement().text().toULongLong();
 			} else if (node2.toElement().tagName() == "in_reply_to_status_id") {
-				replyStatusId = node2.toElement().text().toUInt();
+				replyStatusId = node2.toElement().text().toULongLong();
 			} else if (node2.toElement().tagName() == "in_reply_to_user_id") {
-				replyUserID = node2.toElement().text().toUInt();
+				replyUserID = node2.toElement().text().toULongLong();
 			} else if (node2.toElement().tagName() == "user") {
 				QDomNode node3 = node2.firstChild();
 				while (!node3.isNull()) {
@@ -726,7 +745,7 @@ void MainWindow::updated(const QByteArray &buffer, int type) {
 	QDomNode node = root.firstChild();
 	QString html = "";
 	QString trayMessage = "";
-	uint maxId = twitterTabs[type].lastId;
+	quint64 maxId = twitterTabs[type].lastId;
 	int j = 0;
 	while (!node.isNull()) {
 		if (node.toElement().tagName() != "direct_message") {
@@ -734,14 +753,14 @@ void MainWindow::updated(const QByteArray &buffer, int type) {
 		}
 		QDomNode node2 = node.firstChild();
 		QString message = "", timeStr = "", user = "", image = "", imageRecipient = "",recipientUser = "";
-		uint id = 0;
+		quint64 id = 0;
 		while (!node2.isNull()) {
 			if (node2.toElement().tagName() == "created_at") {
 				timeStr = node2.toElement().text();
 			} else if (node2.toElement().tagName() == "text") {
 				message = node2.toElement().text();
 			} else if (node2.toElement().tagName() == "id") {
-				id = node2.toElement().text().toUInt();
+				id = node2.toElement().text().toULongLong();
 			} else if (node2.toElement().tagName() == "sender_screen_name") {
 				user = node2.toElement().text();
 			} else if (node2.toElement().tagName() == "recipient_screen_name") {
@@ -825,17 +844,17 @@ void MainWindow::updated(const QByteArray &buffer, int type) {
 			QDomNode node = root.firstChild();
 			QString html = "";
 			QString trayMessage = "";
-			uint maxId = twitterTabs[type].lastId;
+			quint64 maxId = twitterTabs[type].lastId;
 			int a = 0;
 			int b = 0;
 			int j = 0;
 			QByteArray buf=buffer;
 			while (buf.indexOf("<entry>", a)!=-1 && buf.indexOf("<entry>", a)<buf.indexOf("</feed>", 0)) {
-				uint id = 0;
+				quint64 id = 0;
 				QString message = "", timeStr = "", user = "", image = "";
 				a=buf.indexOf("<id>", a)+32;
 				b=buf.indexOf("</id>", a);
-				id=buf.mid(a,b-a).toUInt();
+				id=buf.mid(a,b-a).toULongLong();
 				a=buf.indexOf("<published>", a)+11;
 				b=buf.indexOf("</published>", a);
 				timeStr=buf.mid(a,b-a);
