@@ -47,6 +47,7 @@
 #include "Twitter.h"
 #include "OptionsDialog.h"
 #include "LogsDialog.h"
+#include "FriendsMgmtDialog.h"
 
 #include "ui_MainWindow.h"
 
@@ -70,11 +71,11 @@ const int DEFAULT_MESSAGES_PER_TRAY = 10;
 class TwitterTab {
 public:
 	TwitterWidget *twitterWidget;
-	uint lastId;
+	quint64 lastId;
 	QScrollArea *scrollArea;
 	int lastUpdateTime;
 
-	TwitterTab(QScrollArea *scrollArea, TwitterWidget *twitterWidget, uint lastId) {
+	TwitterTab(QScrollArea *scrollArea, TwitterWidget *twitterWidget, quint64 lastId) {
 		this->scrollArea = scrollArea;
 		this->twitterWidget = twitterWidget;
 		this->lastId = lastId;
@@ -117,13 +118,16 @@ public:
 	StatusTextEdit *statusTextEdit;
 	OptionsDialog *optionsDialog;
 	LogsDialog *logsDialog;
+        FriendsMgmtDialog *friendsMgmtDialog;
 	TwitterTab twitterTabs[TWITTER_TABS];
 	Twitter twitter;
 	QMap<QString, int> monthes;
 	bool verticalAlignControl;
 	bool placeTabsVertically;
+	bool keepFocusAfterUpdate;
 	bool updatesNotification;
 	bool usernameUnderAvatar;
+	bool openUserProfileInBrowser;
 
 	QString replyStatusID;
 	bool isReply;
