@@ -1,5 +1,94 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="ru">
+<!DOCTYPE TS>
+<TS version="2.0" language="ru">
+<context>
+    <name>FriendsMgmtDialog</name>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.cpp" line="146"/>
+        <source>Blocking : %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.cpp" line="157"/>
+        <source>Unblocking : %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../src/FriendsMgmtDialog.cpp" line="202"/>
+        <source>%n friend(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../src/FriendsMgmtDialog.cpp" line="205"/>
+        <source>%n follower(s)</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../src/FriendsMgmtDialog.cpp" line="208"/>
+        <source>%n blocked</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.cpp" line="477"/>
+        <source>Screenname contains illegal character: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.ui" line="14"/>
+        <source>Friends Management</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.ui" line="28"/>
+        <source>Friends</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.ui" line="44"/>
+        <source>new friend:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.ui" line="57"/>
+        <source>add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.ui" line="72"/>
+        <source>Followers</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.ui" line="77"/>
+        <source>Blocked</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/FriendsMgmtDialog.ui" line="108"/>
+        <source>Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FriendsMgmtWidget</name>
+    <message>
+        <location filename="../src/FriendsMgmtWidget.cpp" line="117"/>
+        <source>Blocking will prevent %1 from following you. And you won&apos;t see their tweets in your timeline. Are you sure you want to block?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LogsDialog</name>
     <message>
@@ -11,137 +100,157 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="218"/>
+        <location filename="../src/MainWindow.cpp" line="245"/>
+        <source>Pick an image</source>
+        <translation>Выберите изображение</translation>
+    </message>
+    <message>
+        <source>Image Files (*.png *.jpg *.jpeg *.bmp *.JPG *.JPEG *.PNG *.GIF)</source>
+        <translation type="obsolete">Файлы изображений (*.png *.jpg *.jpeg *.bmp *.JPG *.JPEG *.PNG *.GIF)</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="245"/>
+        <source>Image Files (*.png *.jpg *.jpeg *.bmp *.JPG *.JPEG *.PNG *.GIF *.BMP)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="256"/>
         <source>&amp;Show / Hide</source>
         <translation>&amp;Показать / Скрыть</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="220"/>
+        <location filename="../src/MainWindow.cpp" line="258"/>
         <source>&amp;Quit</source>
         <translation>&amp;Выход</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="741"/>
+        <location filename="../src/MainWindow.cpp" line="737"/>
+        <location filename="../src/MainWindow.cpp" line="833"/>
         <source>Qwit updates</source>
         <translation>Обновления Qwit</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="13"/>
+        <location filename="../src/MainWindow.ui" line="14"/>
         <source>Qwit</source>
         <translation>Qwit</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="39"/>
+        <location filename="../src/MainWindow.ui" line="40"/>
         <source>What are you doing?</source>
         <translation>Что вы сейчас делаете?</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="205"/>
+        <location filename="../src/MainWindow.ui" line="206"/>
         <source>Left characters count - please, do not exceed this number</source>
         <translation>Количество оставшихся символов - пожалуйста, не превышайте это число</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="214"/>
+        <location filename="../src/MainWindow.ui" line="215"/>
         <source>140</source>
         <translation>140</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="236"/>
+        <location filename="../src/MainWindow.ui" line="258"/>
         <source>Home</source>
         <translation>Главная</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="239"/>
+        <location filename="../src/MainWindow.ui" line="261"/>
         <source>Your and your friends&apos; timeline</source>
         <translation>Сообщения от вас и ваших друзей</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="244"/>
+        <location filename="../src/MainWindow.ui" line="266"/>
         <source>Public</source>
         <translation>Все</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="247"/>
+        <location filename="../src/MainWindow.ui" line="269"/>
         <source>Public timeline</source>
         <translation>Сообщения ото всех</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="252"/>
+        <location filename="../src/MainWindow.ui" line="274"/>
         <source>Replies</source>
         <translation>Ответы</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="255"/>
+        <location filename="../src/MainWindow.ui" line="277"/>
         <source>Replies to you</source>
         <translation>Ответы вам</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="260"/>
+        <location filename="../src/MainWindow.ui" line="282"/>
         <source>Custom</source>
         <translation>Отдельно</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="263"/>
+        <location filename="../src/MainWindow.ui" line="285"/>
         <source>Custom user timeline</source>
         <translation>Сообщения отдельного пользователя</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="273"/>
+        <location filename="../src/MainWindow.ui" line="295"/>
         <source>Username:</source>
         <translation>Имя пользователя:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="369"/>
+        <location filename="../src/MainWindow.ui" line="396"/>
+        <source>Friends Management</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.ui" line="425"/>
         <source>Refresh</source>
         <translation>Обновить</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="379"/>
+        <location filename="../src/MainWindow.ui" line="435"/>
         <source>Ctrl+R</source>
         <translation>Ctrl+R</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="398"/>
+        <location filename="../src/MainWindow.ui" line="460"/>
         <source>Options</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="441"/>
+        <location filename="../src/MainWindow.ui" line="515"/>
         <source>Quit</source>
         <translation>Выход</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="288"/>
+        <location filename="../src/MainWindow.ui" line="310"/>
         <source>Inbox</source>
         <translation>Входящие</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="291"/>
+        <location filename="../src/MainWindow.ui" line="313"/>
         <source>Direct messages inbox</source>
         <translation>Входящие сообщения</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="296"/>
+        <location filename="../src/MainWindow.ui" line="318"/>
         <source>Outbox</source>
         <translation>Исходящие</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="299"/>
+        <location filename="../src/MainWindow.ui" line="321"/>
         <source>Direct messages outbox</source>
         <translation>Исходящие сообщения</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="304"/>
+        <location filename="../src/MainWindow.ui" line="326"/>
         <source>Search</source>
         <translation>Поиск</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="317"/>
+        <location filename="../src/MainWindow.ui" line="339"/>
         <source>Search:</source>
         <translation>Искать:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.ui" line="307"/>
+        <location filename="../src/MainWindow.ui" line="329"/>
         <source>Search for messages</source>
         <translation>Поиск сообщений</translation>
     </message>
@@ -149,137 +258,147 @@
 <context>
     <name>OptionsDialog</name>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="13"/>
+        <location filename="../src/OptionsDialog.ui" line="14"/>
         <source>Options</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="25"/>
+        <location filename="../src/OptionsDialog.ui" line="26"/>
         <source>General</source>
         <translation>Общие</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="66"/>
+        <location filename="../src/OptionsDialog.ui" line="67"/>
         <source>Update interval:</source>
         <translation>Интервал обновлений:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="79"/>
+        <location filename="../src/OptionsDialog.ui" line="80"/>
         <source>Number of messages per page:</source>
         <translation>Количество сообщений на странице:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="184"/>
+        <location filename="../src/OptionsDialog.ui" line="176"/>
+        <source>Open user profile in browser on username click</source>
+        <translation>Открывать профиль пользователя в браузере</translation>
+    </message>
+    <message>
+        <location filename="../src/OptionsDialog.ui" line="186"/>
+        <source>Keep focus on the text field after status update</source>
+        <translation>Оставлять фокус ввода в текстовом поле после обновления статуса</translation>
+    </message>
+    <message>
+        <location filename="../src/OptionsDialog.ui" line="209"/>
         <source>Connection</source>
         <translation>Соединение</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="192"/>
+        <location filename="../src/OptionsDialog.ui" line="217"/>
         <source>use proxy</source>
         <translation>использовать прокси</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="199"/>
+        <location filename="../src/OptionsDialog.ui" line="224"/>
         <source>Proxy address:</source>
         <translation>Адрес прокси-сервера:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="212"/>
+        <location filename="../src/OptionsDialog.ui" line="237"/>
         <source>Proxy port:</source>
         <translation>Порт прокси-сервера:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="225"/>
+        <location filename="../src/OptionsDialog.ui" line="250"/>
         <source>Proxy username:</source>
         <translation>Имя пользователя:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="238"/>
+        <location filename="../src/OptionsDialog.ui" line="263"/>
         <source>Proxy password:</source>
         <translation>Пароль:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="255"/>
+        <location filename="../src/OptionsDialog.ui" line="280"/>
         <source>save proxy password</source>
         <translation>сохранять пароль для прокси</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="278"/>
+        <location filename="../src/OptionsDialog.ui" line="303"/>
         <source>Authentication</source>
         <translation>Аутентификация</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="286"/>
+        <location filename="../src/OptionsDialog.ui" line="311"/>
         <source>Username or email:</source>
         <translation>Имя пользователя или email:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="299"/>
+        <location filename="../src/OptionsDialog.ui" line="324"/>
         <source>Password:</source>
         <translation>Пароль:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="316"/>
+        <location filename="../src/OptionsDialog.ui" line="341"/>
         <source>save password</source>
         <translation>сохранять пароль</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="361"/>
+        <location filename="../src/OptionsDialog.ui" line="386"/>
         <source>Save options</source>
         <translation>Сохранить настройки</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="368"/>
+        <location filename="../src/OptionsDialog.ui" line="393"/>
         <source>Reset options</source>
         <translation>Сбросить настройки</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="46"/>
+        <location filename="../src/OptionsDialog.ui" line="47"/>
         <source>Service base URL:</source>
         <translation>Базовый адрес сервиса:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="56"/>
+        <location filename="../src/OptionsDialog.ui" line="57"/>
         <source>Service API URL:</source>
         <translation>Адрес API сервиса:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="148"/>
+        <location filename="../src/OptionsDialog.ui" line="149"/>
         <source>Notify about updates</source>
         <translation>Информировать об обновлениях</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="36"/>
+        <location filename="../src/OptionsDialog.ui" line="37"/>
         <source>Greeting message:</source>
         <translation>Приветствие:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="92"/>
+        <location filename="../src/OptionsDialog.ui" line="93"/>
         <source>Number of messages per tray:</source>
         <translation>Количество сообщений в уведомлении:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="138"/>
+        <location filename="../src/OptionsDialog.ui" line="139"/>
         <source>Username under avatar</source>
         <translation>Имя пользователя под аватар</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="115"/>
+        <location filename="../src/OptionsDialog.ui" line="116"/>
         <source>Display retweet tag after text instead of in front</source>
         <translation>Отображать тег ретвита после текста а не перед ним</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="105"/>
+        <location filename="../src/OptionsDialog.ui" line="106"/>
         <source>Retweeting tag:</source>
         <translation>Тэг ретвита:</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="158"/>
+        <location filename="../src/OptionsDialog.ui" line="159"/>
         <source>Place controls vertically</source>
         <translation>Расположить кнопки вертикально</translation>
     </message>
     <message>
-        <location filename="../src/OptionsDialog.ui" line="168"/>
+        <location filename="../src/OptionsDialog.ui" line="169"/>
         <source>Place tabs vertically</source>
         <translation>Расположить вкладки вертикально</translation>
     </message>
@@ -287,32 +406,38 @@
 <context>
     <name>Twitter</name>
     <message>
-        <location filename="../src/Twitter.cpp" line="140"/>
+        <location filename="../src/Twitter.cpp" line="142"/>
         <source>Error sending status: %1</source>
         <translation>Ошибка при отправлении статуса: %1</translation>
     </message>
     <message>
-        <location filename="../src/Twitter.cpp" line="143"/>
+        <location filename="../src/Twitter.cpp" line="145"/>
         <source>Status sent: %1</source>
         <translation>Статус отправлен: %1</translation>
     </message>
     <message>
-        <location filename="../src/Twitter.cpp" line="149"/>
+        <location filename="../src/Twitter.cpp" line="151"/>
         <source>Error while updating timeline: %1</source>
         <translation>Ошибка обновления: %1</translation>
     </message>
     <message>
-        <location filename="../src/Twitter.cpp" line="153"/>
+        <location filename="../src/Twitter.cpp" line="155"/>
         <source>Timeline updated: %1</source>
         <translation>Сообщения обновлены: %1</translation>
     </message>
     <message>
-        <location filename="../src/Twitter.cpp" line="134"/>
+        <location filename="../src/Twitter.cpp" line="191"/>
+        <source>SSL Error while updating/sending: %1</source>
+        <translation>Ошибка SSL: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/Twitter.cpp" line="132"/>
+        <location filename="../src/Twitter.cpp" line="136"/>
         <source>Updating timeline: %1</source>
         <translation>Обновление сообщения: %1</translation>
     </message>
     <message>
-        <location filename="../src/Twitter.cpp" line="95"/>
+        <location filename="../src/Twitter.cpp" line="104"/>
         <source>Sending status: %1</source>
         <translation>Отправка статуса: %1</translation>
     </message>
@@ -320,7 +445,7 @@
 <context>
     <name>TwitterWidget</name>
     <message numerus="yes">
-        <location filename="../src/TwitterWidget.cpp" line="267"/>
+        <location filename="../src/TwitterWidget.cpp" line="149"/>
         <source>about %n second(s) ago</source>
         <translation>
             <numerusform>около %n секунды назад</numerusform>
@@ -329,7 +454,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/TwitterWidget.cpp" line="269"/>
+        <location filename="../src/TwitterWidget.cpp" line="151"/>
         <source>about %n minute(s) ago</source>
         <translation>
             <numerusform>около %n минуты назад</numerusform>
@@ -338,7 +463,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/TwitterWidget.cpp" line="271"/>
+        <location filename="../src/TwitterWidget.cpp" line="153"/>
         <source>about %n hour(s) ago</source>
         <translation>
             <numerusform>около %n часа назад</numerusform>
@@ -347,7 +472,7 @@
         </translation>
     </message>
     <message numerus="yes">
-        <location filename="../src/TwitterWidget.cpp" line="273"/>
+        <location filename="../src/TwitterWidget.cpp" line="155"/>
         <source>about %n day(s) ago</source>
         <translation>
             <numerusform>около %n дня назад</numerusform>
@@ -356,7 +481,7 @@
         </translation>
     </message>
     <message>
-        <location filename="../src/TwitterWidget.cpp" line="266"/>
+        <location filename="../src/TwitterWidget.cpp" line="148"/>
         <source>Just now</source>
         <translation>Только что</translation>
     </message>
@@ -364,17 +489,17 @@
 <context>
     <name>UserpicsDownloader</name>
     <message>
-        <location filename="../src/UserpicsDownloader.cpp" line="43"/>
+        <location filename="../src/UserpicsDownloader.cpp" line="45"/>
         <source>Downloading: %1</source>
         <translation>Загрузка: %1</translation>
     </message>
     <message>
-        <location filename="../src/UserpicsDownloader.cpp" line="57"/>
+        <location filename="../src/UserpicsDownloader.cpp" line="59"/>
         <source>Error while downloading userpic: %1</source>
         <translation>Ошибка при загрузке изображения пользователя: %1</translation>
     </message>
     <message>
-        <location filename="../src/UserpicsDownloader.cpp" line="62"/>
+        <location filename="../src/UserpicsDownloader.cpp" line="64"/>
         <source>Downloaded: %1</source>
         <translation>Загружено: %1</translation>
     </message>
